summaryrefslogtreecommitdiff
path: root/keyboards/gmmk/gmmk2/p96/iso/iso.c
diff options
context:
space:
mode:
Diffstat (limited to 'keyboards/gmmk/gmmk2/p96/iso/iso.c')
-rw-r--r--keyboards/gmmk/gmmk2/p96/iso/iso.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/keyboards/gmmk/gmmk2/p96/iso/iso.c b/keyboards/gmmk/gmmk2/p96/iso/iso.c
index 40d28818b0..f6b3528cb4 100644
--- a/keyboards/gmmk/gmmk2/p96/iso/iso.c
+++ b/keyboards/gmmk/gmmk2/p96/iso/iso.c
@@ -18,8 +18,8 @@
#ifdef RGB_MATRIX_ENABLE
-const aw_led g_aw_leds[RGB_MATRIX_LED_COUNT] = {
-/* Refer to IS31 manual for these locations
+const aw20216s_led_t g_aw20216s_leds[RGB_MATRIX_LED_COUNT] = {
+/* Refer to AW20216S manual for these locations
* driver
* | R location
* | | G location